@@ -143,8 +143,6 @@ brasero_burn_options_add_source (BraseroBurnOptions *self,
 
 	gtk_container_add (GTK_CONTAINER (priv->source_placeholder), priv->source);
 	gtk_widget_show (priv->source_placeholder);
-
-	brasero_dest_selection_choose_best (BRASERO_DEST_SELECTION (priv->selection));
 }
 
 void
@@ -808,7 +806,6 @@ static void
 brasero_burn_options_setup_data (BraseroBurnOptions *self)
 {
 	GSList *tracks;
-	GtkWidget *options;
 	BraseroBurnOptionsPrivate *priv;
 
 	priv = BRASERO_BURN_OPTIONS_PRIVATE (self);
@@ -832,11 +829,6 @@ brasero_burn_options_setup_data (BraseroBurnOptions *self)
 	brasero_burn_options_set_type_shown (BRASERO_BURN_OPTIONS (self),
 					     BRASERO_MEDIA_TYPE_WRITABLE|
 					     BRASERO_MEDIA_TYPE_FILE);
-
-	/* create the options box */
-	options = brasero_data_options_new (BRASERO_BURN_SESSION (priv->session));
-	gtk_widget_show (options);
-	brasero_burn_options_add_options (self, options);
 }
 
 static void
@@ -982,6 +974,10 @@ brasero_burn_options_set_property (GObject *object,
 
 		brasero_burn_options_build_contents (BRASERO_BURN_OPTIONS (object));
 		brasero_burn_options_setup (BRASERO_BURN_OPTIONS (object));
+
+		/* Only try to set a better drive if there isn't one already set */
+		if (!brasero_burn_session_get_burner (BRASERO_BURN_SESSION (priv->session)))
+			brasero_dest_selection_choose_best (BRASERO_DEST_SELECTION (priv->selection));
 		break;
 	default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
