@@ -229,8 +229,6 @@ brasero_src_image_update (BraseroSrcImage *self)
 	/* See if information retrieval went fine and/or is ready */
 	status = brasero_status_new ();
 	result = brasero_track_get_status (BRASERO_TRACK (priv->track), status);
-	brasero_status_free (status);
-
 	if (result == BRASERO_BURN_NOT_READY) {
 		/* Translators: %s is a path */
 		string = g_strdup_printf (_("\"%s\": loading"), path);
@@ -240,6 +238,11 @@ brasero_src_image_update (BraseroSrcImage *self)
 	else if (result != BRASERO_BURN_OK) {
 		/* Translators: %s is a path and image refers to a disc image */
 		string = g_strdup_printf (_("\"%s\": unknown image type"), path);
+
+		error = brasero_status_get_error (status);
+		if (!error)
+			goto end;
+
 		gtk_widget_set_tooltip_text (GTK_WIDGET (self), error->message);
 		brasero_src_image_error (self, error);
 		g_error_free (error);
@@ -260,6 +263,7 @@ brasero_src_image_update (BraseroSrcImage *self)
 
 end:
 
+	brasero_status_free (status);
 	if (string) {
 		/* This is hackish and meant to avoid ellipsization to make the
 		 * label to small. */
@@ -568,7 +572,8 @@ brasero_src_image_init (BraseroSrcImage *object)
 		g_object_unref (file);
 	}
 	g_free (uri);
-		 
+
+	/* Translators: this is a disc image */
 	string = g_strdup_printf ("<i>%s</i>", _("Click here to select an _image"));
 	label = gtk_label_new_with_mnemonic (string);
 	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
