@@ -21,9 +21,10 @@
 #define _BRASERO_APP_H_
 
 #include <glib-object.h>
-
 #include <gtk/gtk.h>
 
+#include "brasero-session-cfg.h"
+
 G_BEGIN_DECLS
 
 #define BRASERO_TYPE_APP             (brasero_app_get_type ())
@@ -48,11 +49,24 @@ struct _BraseroApp
 
 GType brasero_app_get_type (void) G_GNUC_CONST;
 
-GtkWidget *
+BraseroApp *
 brasero_app_new (void);
 
+BraseroApp *
+brasero_app_get_default (void);
+
 void
-brasero_app_run (BraseroApp *app);
+brasero_app_set_parent (BraseroApp *app,
+			guint xid);
+
+void
+brasero_app_set_toplevel (BraseroApp *app, GtkWindow *window);
+
+void
+brasero_app_create_mainwin (BraseroApp *app);
+
+gboolean
+brasero_app_run_mainwin (BraseroApp *app);
 
 gboolean
 brasero_app_is_running (BraseroApp *app);
@@ -69,6 +83,23 @@ brasero_app_alert (BraseroApp *app,
 		   const gchar *secondary_message,
 		   GtkMessageType type);
 
+gboolean
+brasero_app_burn (BraseroApp *app,
+		  BraseroBurnSession *session);
+
+gboolean
+brasero_app_burn_options (BraseroApp *app,
+			  BraseroSessionCfg *session);
+
+void
+brasero_app_burn_image (BraseroApp *app,
+			const gchar *uri);
+
+void
+brasero_app_copy_disc (BraseroApp *app,
+		       const gchar *device,
+		       const gchar *cover);
+
 void
 brasero_app_blank (BraseroApp *app,
 		   const gchar *device);
@@ -77,12 +108,6 @@ void
 brasero_app_check (BraseroApp *app,
 		   const gchar *device);
 
-void
-brasero_app_get_geometry (BraseroApp *app,
-			  gint *width,
-			  gint *height,
-			  gboolean *maximised);
-
 GtkWidget *
 brasero_app_get_statusbar1 (BraseroApp *app);
 
@@ -95,6 +120,21 @@ brasero_app_get_ui_manager (BraseroApp *app);
 GtkWidget *
 brasero_app_get_project_manager (BraseroApp *app);
 
+/**
+ * Session management
+ */
+
+#define BRASERO_SESSION_TMP_PROJECT_PATH	"brasero-tmp-project"
+
+const gchar *
+brasero_app_get_saved_contents (BraseroApp *app);
+
+gboolean
+brasero_app_save_contents (BraseroApp *app,
+			   gboolean cancellable);
+void
+brasero_app_save_window_state (BraseroApp *app);
+
 G_END_DECLS
 
 #endif /* _BRASERO_APP_H_ */
