@@ -523,7 +523,7 @@ brasero_data_disc_name_edited_cb (GtkCellRendererText *cellrenderertext,
  */
 
 static void
-brasero_data_disc_use_overburn_response_cb (GtkButton *button,
+brasero_data_disc_use_overburn_response_cb (BraseroDiscMessage *message,
 					    GtkResponseType response,
 					    BraseroDataDisc *self)
 {
@@ -818,6 +818,42 @@ brasero_data_disc_unknown_uri_cb (BraseroTrackDataCfg *vfs,
 	g_free (name);
 }
 
+static void
+brasero_data_disc_joliet_rename_cb (BraseroTrackDataCfg *project,
+				    BraseroDataDisc *self)
+{
+	BraseroDataDiscPrivate *priv;
+	GtkWidget *dialog;
+	gchar *secondary;
+	gint answer;
+
+	priv = BRASERO_DATA_DISC_PRIVATE (self);
+
+	dialog = brasero_app_dialog (brasero_app_get_default (),
+				     _("Should files be renamed to be fully Windows-compatible?"),
+				     GTK_BUTTONS_NONE,
+				     GTK_MESSAGE_WARNING);
+	secondary = g_strdup_printf ("%s\n%s",
+				     _("Some files don't have a suitable name for a fully Windows-compatible CD."),
+				     _("Those names should be changed and truncated to 64 characters."));
+	gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog), secondary);
+	g_free (secondary);
+
+	gtk_dialog_add_button (GTK_DIALOG (dialog), _("_Rename for Full Windows Compatibility"), GTK_RESPONSE_YES);
+	gtk_dialog_add_button (GTK_DIALOG (dialog), _("_Disable Full Windows Compatibility"), GTK_RESPONSE_CANCEL);
+
+	gtk_widget_show_all (dialog);
+	answer = gtk_dialog_run (GTK_DIALOG (dialog));
+	gtk_widget_destroy (dialog);
+
+	if (answer == GTK_RESPONSE_YES)
+		brasero_track_data_add_fs (BRASERO_TRACK_DATA (priv->project),
+					   BRASERO_IMAGE_FS_JOLIET);
+	else
+		brasero_track_data_rm_fs (BRASERO_TRACK_DATA (priv->project),
+					  BRASERO_IMAGE_FS_JOLIET);
+}
+
 static gboolean
 brasero_data_disc_name_collision_cb (BraseroTrackDataCfg *project,
 				     const gchar *name,
@@ -2194,6 +2230,10 @@ brasero_data_disc_init (BraseroDataDisc *object)
 			  "name-collision",
 			  G_CALLBACK (brasero_data_disc_name_collision_cb),
 			  object);
+	g_signal_connect (priv->project,
+			  "joliet-rename",
+			  G_CALLBACK (brasero_data_disc_joliet_rename_cb),
+			  object);
 	g_signal_connect (priv->project,
 			  "row-inserted",
 			  G_CALLBACK (brasero_data_disc_contents_added_cb),
